#
# spec file for package libmspack
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libmspack
Version:        0.5
Release:        8.3.1
# "alpha" in the version string just says that it is an alpha version.
%define _version %{version}alpha
Summary:        Library That Implements Different Microsoft Compressions
License:        LGPL-2.1-only
Group:          System/Libraries
Url:            http://www.cabextract.org.uk/libmspack/
# Warning, OBS download service does not work at http://www.cabextract.org.uk/
#Source:        http://www.cabextract.org.uk/libmspack/%{name}-%{_version}.tar.gz
Source:         %{name}-%{_version}.tar.gz
Source2:        baselibs.conf
# PATCH-FIX-UPSTREAM libmspack-resize-buffer.patch https://github.com/kyz/libmspack/commit/40ef1b4093d77ad3a5cfcee1f5cb6108b3a3bcc2 -- CAB block input buffer is one byte too small.
Patch0:         %{name}-resize-buffer.patch
# PATCH-FIX-UPSTREAM libmspack-fix-bounds-checking.patch https://github.com/kyz/libmspack/commit/72e70a921f0f07fee748aec2274b30784e1d312a --  Fix off-by-one bounds check.
Patch1:         %{name}-fix-bounds-checking.patch
# PATCH-FIX-UPSTREAM libmspack-reject-blank-filenames.patch https://github.com/kyz/libmspack/commit/8759da8db6ec9e866cb8eb143313f397f925bb4f --  Avoid returning etries that are blank.
Patch2:         %{name}-reject-blank-filenames.patch
# PATCH-FIX-UPSTREAM libmspack-fix-test-install.patch https://github.com/kyz/libmspack/commit/7cadd489698be117c47efcadd742651594429e6d --  Add anti "../" and leading slash protection to chmextract.
Patch3:         %{name}-fix-test-install.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  pkg-config

%description
The purpose of libmspack is to provide both compression and
decompression of some loosely related file formats used by Microsoft.
Currently the most common formats are implemented.

%package -n libmspack0
Summary:        Library That Implements Different Microsoft Compressions
# OpenSUSE <= 10.3, SLES <= 10:
Group:          System/Libraries
Provides:       libmspack = %{version}-%{release}
Obsoletes:      libmspack < %{version}-%{release}

%description -n libmspack0
The purpose of libmspack is to provide both compression and
decompression of some loosely related file formats used by Microsoft.
Currently the most common formats are implemented.

%package devel
Summary:        Static libraries, header files and documentation for libmspack
Group:          Development/Libraries/C and C++
Requires:       libmspack0 = %{version}

%description devel
The libmspack-devel package contains the header files and static
libraries necessary for developing programs using libmspack.

%prep
%setup -q -n %{name}-%{_version}
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1

%build
%configure\
	--disable-static
make %{?_smp_mflags}

%install
%makeinstall
rm $RPM_BUILD_ROOT%{_libdir}/*.*a

%post -n libmspack0 -p /sbin/ldconfig

%postun -n libmspack0 -p /sbin/ldconfig

%files -n libmspack0
%defattr(-,root,root)
%{_libdir}/*.so.*
%doc AUTHORS COPYING.LIB ChangeLog README TODO

%files devel
%defattr(-,root,root)
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/*

%changelog
* Fri Oct 26 2018 Marketa Calabkova <mcalabkova@suse.com>
- Added patches:
  * libmspack-resize-buffer.patch -- CAB block input buffer is one
    byte too small for maximal Quantum block.
  * libmspack-fix-bounds-checking.patch --  Fix off-by-one bounds
    check on CHM PMGI/PMGL chunk numbers and reject empty filenames.
  * libmspack-reject-blank-filenames.patch -- Avoid returning CHM
    file entries that are "blank" because they have embedded null
    bytes.
  * libmspack-fix-test-install.patch -- Add anti "../" and leading slash
    protection to chmextract (here chmx).
- Fixed bugs:
  * CVE-2018-18584 (bsc#1113038)
  * CVE-2018-18585 (bsc#1113039)
  * CVE-2018-18586 (bsc#1113040)
* Fri Feb 27 2015 sbrabec@suse.cz
- Remove problematic libmspack-qtmd_decompress-loop.patch
  (bnc#912214#c10).
  Version 0.5 has a correct fix dated 2015-01-05.
* Wed Feb 11 2015 p.drouand@gmail.com
- Update to version 0.5
  * Please read the changelog; too many things to list
* Tue Jan 20 2015 sbrabec@suse.cz
- Fix possible infinite loop caused DoS (bnc912214, CVE-2014-9556,
  libmspack-qtmd_decompress-loop.patch).
* Fri Apr  4 2014 jengelh@inai.de
- Add baselibs.conf: wxWidgets-32bit depends on libmspack0-32bit
* Mon Jun 24 2013 werner@suse.de
- Avoid Source URL for http://www.cabextract.org.uk/ as this does
  not work
* Sat Jun 22 2013 dimstar@opensuse.org
- Update to version 0.4alpha:
  + This release adds support for the Microsoft Exchange Offline
    Address Book (OAB) format, both compressed and incremental
    variants.
* Wed Jul 18 2012 aj@suse.de
- Remove autoreconf call and libtool buildrequires, they are not
  needed anymore.
* Wed Jul 18 2012 sbrabec@suse.cz
- Update to version 0.3alpha:
  * code cleanup and build system update
  * handle corrupted cabinet files better
  * handle special cases of cabinet files
- License update: LGPL-2.1 only.
* Mon Feb 27 2012 cfarrell@suse.com
- license update: LGPL-2.1+
  No indication of GPL-2.0+ code in the package
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Sun Nov 20 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Use %%_smp_mflags for parallel building
* Sat Nov 19 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Wed Dec 22 2010 andreas.hanke@gmx-topmail.de
- update to version 0.2alpha (#660942):
  * matches cabextract-1.3, fixing CVE-2010-2800 and CVE-2010-2801
  * adds pkg-config support
  * obsoletes half of libmspack-warnings.patch
- remove self-obsoletion
- drop -D_POSIX_SOURCE as it breaks the build with this version
- drop empty NEWS file
* Tue Jan 15 2008 sbrabec@suse.cz
- Applied shared library packaging policy.
- Removed unneeded static library and .la file.
* Fri Oct 20 2006 sbrabec@suse.cz
- Updated to version 0.0.20060920alpha:
  * Bug fixes.
  * Write an mspack_system implementation that can handle normal
    disk files, open file handles, open file descriptors and raw
    memory all at the same time.
  * Added a program for dumping useful data from CHM files.
  * Added a new test example which shows an mspack_system
    implementation that reads and writes from memory only.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Nov 22 2004 ro@suse.de
- "sed -i" does not work on older distributions
* Wed Apr 14 2004 mcihar@suse.cz
- include some documentation
* Wed Apr 14 2004 mcihar@suse.cz
- initial packaging
